@@ -1,14 +1,15 @@
+
 #' @title Create a Tidy Data Frame From CRU CL v.2.0 Climatology Variables on Local Disk
 #'
-#'@description This function automates importing CRU CL v.2.0 climatology data
-#'into R and creates a tidy data frame of the data.  If requested, minimum and
-#'maximum temperature may also be automatically calculated as described in the
-#'data readme.txt file.  This function can be useful if you have network
-#'connection issues that mean automated downloading of the files using R
-#'does not work properly.  In this instance it is recommended to use an FTP
-#'client (e.g., FileZilla), web browser or command line command (e.g., wget or
-#'curl) to download the files, save locally and use this function to import the
-#'data into R.
+#'@description Automates importing \acronym{CRU} \acronym{CL} v.2.0 climatology
+#' data and creates a tidy data frame of the data.  If requested, minimum and
+#' maximum temperature may also be automatically calculated as described in the
+#' data readme.txt file.  This function can be useful if you have network
+#' connection issues that mean automated downloading of the files using \pkg{R}
+#' does not work properly.  In this instance it is recommended to use an
+#' \acronym{FTP} client (\emph{e.g.}, FileZilla), web browser or command line
+#' command (\emph{e.g.}, wget or curl) to download the files, save locally and
+#' use this function to import the data into \pkg{R}.
 #'
 #'Nomenclature and units from readme.txt:
 #'\describe{
@@ -25,56 +26,66 @@
 #'\item{wnd}{10 metre windspeed (metres/second)}
 #'\item{elv}{elevation (automatically converted to metres)}
 #'}
-#'For more information see the description of the data provided by CRU,
-#'\url{https://crudata.uea.ac.uk/cru/data/hrg/tmc/readme.txt}
+#'For more information see the description of the data provided by
+#' \acronym{CRU}, \url{https://crudata.uea.ac.uk/cru/data/hrg/tmc/readme.txt}
 #'
 #' @param pre Logical. Fetch precipitation (millimetres/month) from server and
-#'  return in the data frame? Defaults to FALSE.
+#'  return in the data frame? Defaults to \code{FALSE}.
 #' @param pre_cv Logical. Fetch cv of precipitation (percent) from server and
-#' return in the data frame? Defaults to FALSE. NOTE. Setting this to TRUE
-#' will always results in \strong{pre} being set to TRUE and returned as well.
+#' return in the data frame? Defaults to \code{FALSE}. NOTE. Setting this to
+#' \code{TRUE} will always results in \strong{pre} being set to \code{TRUE} and
+#' returned as well.
 #' @param rd0 Logical. Fetch wet-days (number days with >0.1millimetres rain per
-#' month) and return in the data frame? Defaults to FALSE.
+#' month) and return in the data frame? Defaults to \code{FALSE}.
 #' @param dtr Logical. Fetch mean diurnal temperature range (degrees Celsius)
-#' and return it in the data frame? Defaults to FALSE.
+#' and return it in the data frame? Defaults to \code{FALSE}.
 #' @param tmp Logical. Fetch temperature (degrees Celsius) and return it in the
-#' data frame? Defaults to FALSE.
+#' data frame? Defaults to \code{FALSE}.
 #' @param tmn Logical. Calculate minimum temperature values (degrees Celsius)
-#' and return it in the data frame? Defaults to FALSE.
+#' and return it in the data frame? Defaults to \code{FALSE}.
 #' @param tmx Logical. Calculate maximum temperature (degrees Celsius) and
-#' return it in the data frame? Defaults to FALSE.
+#' return it in the data frame? Defaults to \code{FALSE}.
 #' @param reh Logical. Fetch relative humidity and return it in the data frame?
-#' Defaults to FALSE.
+#' Defaults to \code{FALSE}.
 #' @param sunp Logical. Fetch sunshine, percent of maximum possible (percent of
-#' day length) and return it in data frame? Defaults to FALSE.
+#' day length) and return it in data frame? Defaults to \code{FALSE}.
 #' @param frs Logical. Fetch ground-frost records (number of days with ground-
-#' frost per month) and return it in data frame? Defaults to FALSE.
+#' frost per month) and return it in data frame? Defaults to \code{FALSE}.
 #' @param wnd Logical. Fetch 10m wind speed (metres/second) and return it in the
-#' data frame? Defaults to FALSE.
+#' data frame? Defaults to \code{FALSE}.
 #' @param elv Logical. Fetch elevation (converted to metres) and return it in
-#' the data frame? Defaults to FALSE.
-#' @param dsn Local file path where CRU CL v.2.0 .dat.gz files are located.
+#' the data frame? Defaults to \code{FALSE}.
+#' @param dsn Local file path where \acronym{CRU} \acronym{CL} v.2.0 .dat.gz
+#' files are located.
 #'
 #' @examples
-#' # Create a raster stack of precipitation and temperature from locally
-#' # available files
-#' \dontrun{
-#' CRU_pre_tmp <- create_CRU_df(pre = TRUE, tmp = TRUE, dsn = "~/Downloads")
+#' \donttest{
+#' # Create a data frame of temperature from locally available files in the
+#' # tempdir() directory.
+#'
+#' download.file(
+#'   url = "https://crudata.uea.ac.uk/cru/data/hrg/tmc/grid_10min_tmp.dat.gz",
+#'   destfile = file.path(tempdir(), "grid_10min_tmp.dat.gz")
+#' )
+#'
+#' CRU_tmp <- create_CRU_df(tmp = TRUE, dsn = tempdir())
+#'
+#' CRU_tmp
 #'}
 #'
 #' @seealso
 #' \code{\link{get_CRU_df}}
 #'
-#' @return A tidy data frame of CRU CL v. 2.0 climatology elements as a
-#' \code{\link[tibble]{tibble}} object
+#' @return A tidy data frame of \acronym{CRU} \acronym{CL} v. 2.0 climatology
+#' elements as a \code{\link[tibble]{tibble}} object
 #'
 #' @author Adam H Sparks, \email{adamhsparks@@gmail.com}
 #'
 #' @note
 #' This package automatically converts elevation values from kilometres to
 #' metres.
-#'
-#' @export
+#' @export create_CRU_df
+
 create_CRU_df <-   function(pre = FALSE,
                             pre_cv = FALSE,
                             rd0 = FALSE,
@@ -121,5 +132,5 @@ create_CRU_df <-   function(pre = FALSE,
   }
 
   d <- .create_df(tmn, tmx, tmp, dtr, pre, pre_cv, elv, files)
-  return(d)
+  return(tibble::as_tibble(d))
 }
