@@ -2,29 +2,29 @@
 #' @title Download and Create a List of Raster Stack Objects From CRU CL v. 2.0 Climatology Variables
 #'
 #'@description This function automates downloading and importing CRU CL v. 2.0
-#'climatology data into R and creates a list of raster stacks of the data.  If
-#'requested, minimum and maximum temperature may also be automatically
-#'calculated as described in the data readme.txt file.  Data may be cached for
-#'later use by this function, saving time downloading files in future use of the
-#'function.
+#' climatology data into \pkg{R} and creates a list of raster stacks of the
+#' data.  If requested, minimum and maximum temperature may also be
+#' automatically calculated as described in the data readme.txt file.  Data may
+#' be cached for later use by this function, saving time downloading files in
+#' future use of the function.
 #'
-#'Nomenclature and units from readme.txt:
-#'\describe{
-#'\item{pre}{precipitation (millimetres/month)}
-#'  \describe{
-#'    \item{cv}{cv of precipitation (percent)}
-#'  }
-#'\item{rd0}{wet-days (number days with >0.1mm rain per month)}
-#'\item{tmp}{mean temperature (degrees Celsius)}
-#'\item{dtr}{mean diurnal temperature range (degrees Celsius)}
-#'\item{reh}{relative humidity (percent)}
-#'\item{sunp}{sunshine (percent of maximum possible (percent of day length))}
-#'\item{frs}{ground-frost (number of days with ground-frost per month)}
-#'\item{wnd}{10 metre windspeed (metres/second)}
-#'\item{elv}{elevation (automatically converted to metres)}
-#'}
-#'For more information see the description of the data provided by CRU,
-#'\url{https://crudata.uea.ac.uk/cru/data/hrg/tmc/readme.txt}
+#' Nomenclature and units from readme.txt:
+#' \describe{
+#' \item{pre}{precipitation (millimetres/month)}
+#'   \describe{
+#'     \item{cv}{cv of precipitation (percent)}
+#'   }
+#' \item{rd0}{wet-days (number days with >0.1mm rain per month)}
+#' \item{tmp}{mean temperature (degrees Celsius)}
+#' \item{dtr}{mean diurnal temperature range (degrees Celsius)}
+#' \item{reh}{relative humidity (percent)}
+#' \item{sunp}{sunshine (percent of maximum possible (percent of day length))}
+#' \item{frs}{ground-frost (number of days with ground-frost per month)}
+#' \item{wnd}{10 metre windspeed (metres/second)}
+#' \item{elv}{elevation (automatically converted to metres)}
+#' }
+#' For more information see the description of the data provided by CRU,
+#' \url{https://crudata.uea.ac.uk/cru/data/hrg/tmc/readme.txt}
 #'
 #' @param pre Logical.  Fetch precipitation (millimetres/month) from server and
 #' return in the data frame?  Defaults to \code{FALSE}.
@@ -58,16 +58,14 @@
 #' after the initial download and caching.  Defaults to \code{FALSE}.
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' # Download data and create a raster stack of precipitation and temperature
 #' # without caching the data files
 #' CRU_pre_tmp <- get_CRU_stack(pre = TRUE, tmp = TRUE)
 #'
-#' # Download temperature and calculate tmin and tmax, save the data files for
-#' # later use by caching them locally
+#' CRU_pre_tmp
+#' }
 #'
-#' CRU_tmp <- get_CRU_stack(tmp = TRUE, tmn = TRUE, tmx = TRUE, cache = TRUE)
-#'}
 #' @seealso
 #' \code{\link{create_CRU_stack}}
 #' \code{\link{manage_cache}}
@@ -85,9 +83,9 @@
 #' xmin = -180, xmax = 180.  Note that the original wind data include land area
 #' for parts of Antarctica, these data are excluded in the raster stacks
 #' generated by this function.
-
 #'
-#' @export
+#' @export get_CRU_stack
+
 get_CRU_stack <-
   function(pre = FALSE,
            pre_cv = FALSE,
@@ -102,11 +100,9 @@ get_CRU_stack <-
            wnd = FALSE,
            elv = FALSE,
            cache = FALSE) {
-    if (!isTRUE(pre) &
-        !isTRUE(pre_cv) & !isTRUE(rd0) & !isTRUE(tmp) &
+    if (!isTRUE(pre) & !isTRUE(pre_cv) & !isTRUE(rd0) & !isTRUE(tmp) &
         !isTRUE(dtr) & !isTRUE(reh) & !isTRUE(tmn) & !isTRUE(tmx) &
-        !isTRUE(sunp) &
-        !isTRUE(frs) & !isTRUE(wnd) & !isTRUE(elv)) {
+        !isTRUE(sunp) & !isTRUE(frs) & !isTRUE(wnd) & !isTRUE(elv)) {
       stop("\nYou must select at least one element for download.\n",
            call. = FALSE)
     }
